#!/bin/bash

MyPWD=$PWD
SOFTWARE=$MyPWD/software
INSTALL=$MyPWD/install_files
DEPLOY=$MyPWD/deploy


if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi

yum -y install glibc.i686 mysql mysql-server subversion dos2unix

mkdir software
mkdir Logs
mkdir install_files
mkdir deploy

# software directory
wget http://download.java.net/glassfish/3.1.2.2/release/glassfish-3.1.2.2-ml.zip -O $MyPWD/software/glassfish-3.1.2.2-ml.zip 
wget http://verity.irss.unc.edu/safe-downloads/jdk-7u17-linux-i586.tar.gz -O $MyPWD/software/jdk-7u17-linux-i586.tar.gz
wget http://apache.mirrors.pair.com//commons/logging/binaries/commons-logging-1.1.1-bin.zip -O $MyPWD/software/commons-logging-1.1.1-bin.zip

cd $MyPWD/software
unzip commons-logging-1.1.1-bin.zip
mv $MyPWD/software/commons-logging-1.1.1/*.jar $MyPWD/software
rm -rf $MyPWD/software/commons-logging-1.1.1

wget http://verity.irss.unc.edu/safe-downloads/mysql-connector-java-5.1.24.tar.gz -O $MyPWD/software/mysql-connector-java-5.1.24.tar.gz
tar vfzx mysql-connector-java-5.1.24.tar.gz
mv $MyPWD/software/mysql-connector-java-5.1.24/*.jar $MyPWD/software
rm -rf $MyPWD/software/mysql-connector-java-5.1.24

rm -f  $MyPWD/software/mysql*.zip
rm -f  $MyPWD/software/commons*.zip

# install_files directory
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/lockss_audit_diff_xpaths.xml" -O $MyPWD/install_files/lockss_audit_diff_xpaths.xml
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/lockss_audit_report.xsd" -O $MyPWD/install_files/lockss_audit_report.xsd 
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/saas-audit-owner-inst-set.txt" -O $MyPWD/install_files/saas-audit-owner-inst-set.txt
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/saas-audit-subject-set.txt" -O $MyPWD/install_files/saas-audit-subject-set.txt
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/SSPSchema_v1_05.xsd" -O $MyPWD/install_files/SSPSchema_v1_05.xsd
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/trac_qq.txt" -O $MyPWD/install_files/trac_qq.txt
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/us-census-region-modified-code-to-label.properties" -O $MyPWD/install_files/us-census-region-modified-code-to-label.properties
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/us-state-code-to-label.properties" -O $MyPWD/install_files/us-state-code-to-label.properties
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/us-state-code-to-region-code.properties" -O $MyPWD/install_files/us-state-code-to-region-code.properties

# deploy directory
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/configurationFiles/birt.war" -O $MyPWD/deploy/birt.war
wget "http://sourceforge.net/p/safearchive/code/HEAD/tree/releases/saas-2.0/ear/safearchiveauditsystem-ear.ear" -O $MyPWD/deploy/safearchiveauditsystem-ear.ear

# Check software directory
if [[ -e $SOFTWARE/jdk-7u17-linux-i586.tar.gz && -e $SOFTWARE/glassfish-3.1.2.2-ml.zip && -e $SOFTWARE/commons-logging-1.1.1.jar && -e $SOFTWARE/commons-logging-1.1.1-javadoc.jar && $SOFTWARE/commons-logging-1.1.1-sources.jar && -e $SOFTWARE/commons-logging-adapters-1.1.1.jar && -e $SOFTWARE/commons-logging-api-1.1.1.jar && -e $SOFTWARE/commons-logging-tests.jar && -e $SOFTWARE/mysql-connector-java-5.1.24-bin.jar ]]
then
   echo "All software is downloaded"
else
   echo "Ensure that correct versions of GlassFish, Java, the following jar files are placed in the $SOFTWARE folder before running setup.sh"
   echo "commons-logging-1.1.1.jar"
   echo "commons-logging-1.1.1-javadoc.jar"
   echo "commons-logging-1.1.1-sources.jar"
   echo "commons-logging-adapters-1.1.1.jar"
   echo "commons-logging-api-1.1.1.jar"
   echo "commons-logging-tests.jar"
   echo "mysql-connector-java-5.1.24-bin.jar"

fi

# Check install_files directory
if [[ -e $INSTALL/lockss_audit_diff_xpaths.xml && -e $INSTALL/lockss_audit_report.xsd && -e $INSTALL/saas-audit-owner-inst-set.txt && -e $INSTALL/saas-audit-subject-set.txt && -e $INSTALL/SSPSchema_v1_05.xsd && -e $INSTALL/trac_qq.txt && -e $INSTALL/us-census-region-modified-code-to-label.properties && -e $INSTALL/us-state-code-to-label.properties && -e $INSTALL/us-state-code-to-region-code.properties ]]
then
   echo "All install files are downloaded"
else
   echo "Ensure that the following files are downloaded from sourceforge and placed into the $INSTALL folder before running setup.sh"
   echo "lockss_audit_diff_xpaths.xml"
   echo "lockss_audit_report.xsd"
   echo "saas-audit-owner-inst-set.txt"
   echo "saas-audit-subject-set.txt"
   echo "SSPSchema_v1_05.xsd"
   echo "trac_qq.txt"
   echo "us-census-region-modified-code-to-label.properties"
   echo "us-state-code-to-label.properties"
   echo "us-state-code-to-region-code.properties"
fi

# Check deploy directory
if [[ -e $DEPLOY/birt.war && -e $DEPLOY/safearchiveauditsystem-ear.ear ]]
then
   echo "All deployment files are downloaded"
else
   echo "Ensure that the following files are downloaded from sourceforge and placed into the $DEPLOY folder before running setup.sh"
   echo "birt.war"
   echo "safearchiveauditsystem-ear.ear"
fi

echo ""
echo ""

echo "If all files have been downloaded you may run ./setup.sh"
