#!/bin/bash

############################################
# AUTHOR: Terry Rowland                    #
# TITLE: SAAS setup script                 #
# DATE: 04/12/2013                         #
# ORGANIZATION: The Odum Institute, UNC    #
# DESCRIPTION: A short script used to      #
#              simplify SAAS installation  #
############################################

#-----------------------------------------------------------------------------------------#
######################### Begin Constant Variables ########################################
MySQLbin=`which mysql`
pathToBin="/usr/local/glassfish3/glassfish/bin"
MyPWD=$PWD
DATE=`date`
logFile="$MyPWD/Logs/setup-$DATE.log"
fireWall="/etc/sysconfig/iptables"
input_files="/usr/safe/data/audit_input_files"

######################## End Constant Variables ###########################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin Color Codes ################################################
black='\E[30;40m'
red='\E[31;40m'
green='\E[32;40m'
yellow='\E[33;40m'
blue='\E[34;40m'
magenta='\E[35;40m'
cyan='\E[36;40m'
white='\E[37;40m'
######################## End Color Codes ##################################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin Input Defaults #############################################

lockssXMLURL_default="homer.irss.unc.edu/lockss.xml"
smtpServer_default="smtp.gmail.com"
smtpUser_default="uncodum"
smtpEmail_default="uncodum@gmail.com"
smtpPassword_default="uncistheplacetobe"
smtpPort_default="465"
SAAS_user_default="Sassy"
SAAS_pw_default="sassafras"
MySQLrootPW_default="rootbeer"
captcha_default="6Ld1PcISAAAAAMzfbHzxQv74PIwE-1LfdRN3N8c8"
daemon_default="debug"
daemonPW_default="CNS-debug"
supportName_default="SafeArchive.org"
supportEmail_default="uncodum1@gmail.com"
timeZone_default="America/New_York"
reportRecipList_default="uncodum@gmail.com, uncodum1@gmail.com"

######################## End Input Defaults ###############################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin Check for Root User ########################################

if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi

######################## End Check for Root User ##########################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin Functions ################################################## 
 
cecho ()                     # Color-echo.
                             # Argument $1 = message
                             # Argument $2 = color
 {
local default_msg=""
                             
 
message=${1:-$default_msg}   # Defaults to default message.
color=${2:-$white}           # Defaults to white, if not specified.

  echo -e "$color"
  echo -n "$message"
  tput sgr0
   
    return
} 

valid_ip(){

    input=$1
    octet1=$(echo $input | cut -d "." -f1)
    octet2=$(echo $input | cut -d "." -f2)
    octet3=$(echo $input | cut -d "." -f3)
    octet4=$(echo $input | cut -d "." -f4)
    stat=0

if [[ $input =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$ ]] && [ $octet1 -le 255 ] && [ $octet2 -le 255 ] && [ $octet3 -le 255 ] && [ $octet4 -le 255 ];
  then
    stat=1
fi

return  $stat

}

print_banner(){
cecho "$1" $cyan
cecho "$2" $red
echo "                                                             "
cecho "  ____         __         _             _     _              " $green
cecho " / ___|  __ _ / _| ___   / \   _ __ ___| |__ (_)__   _____   " $green
cecho " \___ \ / _\` | |_ / _ \ / _ \ | '__/ __| '_ \| |\ \ / / _ \ " $green
cecho "  ___) | (_| |  _|  __// ___ \| | | (__| | | | | \ V /  __/  " $green
cecho " |____/ \__,_|_|  \___/_/   \_\_|  \___|_| |_|_|  \_/ \___|  " $green
echo "                                                             "
echo "                                                             "
cecho "$3" $cyan 
echo "                                                             " 
echo "                                                             " 

}

spinner()
{
    local pid=$1
    local delay=0.35
    local spinstr='|/-\'
    while [ "$(ps a | awk '{print $1}' | grep $pid)" ]; do
        local temp=${spinstr#?}
        printf " [%c]  " "$spinstr"
        local spinstr=$temp${spinstr%"$temp"}
        sleep $delay
        printf "\b\b\b\b\b\b"
    done
    printf "    \b\b\b\b"
}

######################## End Functions ####################################################
#-----------------------------------------------------------------------------------------# 

clear
print_banner "                   W  E  L  C  O  M  E                      " "                       T O   T H E                          " "               I  N  S  T  A  L  L  E  R                    "
touch "$logFile"

#-----------------------------------------------------------------------------------------#  
######################## Begin get user input ############################################# 

read -p "Enter the URL for your LOCKSS XML file. (default: $lockssXMLURL_default) " -e t1
if [ -n "$t1" ]
then 
	lockssXMLURL="$t1"
else	
	lockssXMLURL=$lockssXMLURL_default
fi
echo "LOCKSS XML URL: $lockssXMLURL" > "$logFile" 

read -p "Enter the url of your mail/SMTP server. (default: $smtpServer_default) " -e t1
if [ -n "$t1" ]
then 
	smtpServer="$t1"
else	
	smtpServer=$smtpServer_default
fi
echo "SMTP Server: $smtpServer" >> "$logFile"

read -p "Enter the username for your mail/SMTP account. (default: $smtpUser_default) " -e t1
if [ -n "$t1" ]
then 
	smtpUser="$t1"
else	
	smtpUser=$smtpUser_default
fi
echo "SMTP Username: $smtpUser" >> "$logFile"

read -p "Enter the email address for your mail/SMTP account. (default: $smtpEmail_default) " -e t1
if [ -n "$t1" ]
then 
	smtpEmail="$t1"
else	
	smtpEmail=$smtpEmail_default
fi
echo "SMTP Email: $smtpEmail" >> "$logFile"

read -p "Enter your mail/SMTP password. (default: $smtpPassword_default) " -e t1
if [ -n "$t1" ]
then 
	smtpPassword="$t1"
else	
	smtpPassword=$smtpPassword_default
fi
echo "SMTP Password: $smtpPassword" >> "$logFile"

read -p "Enter your mail/SMTP TCP port number. (default: $smtpPort_default) " -e t1
if [ -n "$t1" ]
then 
	smtpPort="$t1"
else	
	smtpPort=$smtpPort_default
fi
echo "SMTP Port: $smtpPort" >> "$logFile"

read -p "Enter your database username for SAFE Archive. (default: $SAAS_user_default) " -e t1
if [ -n "$t1" ]
then
	SAAS_user="$t1"
else
	SAAS_user=$SAAS_user_default
fi
echo "Database Username: $SAAS_user" >> "$logFile"

read -p "Enter your database password for SAFE Archive (default is $SAAS_pw_default): " -e t1
if [ -n "$t1" ]
then
	SAAS_pw="$t1"
else
	SAAS_pw=$SAAS_pw_default
fi
echo "Database Password: $SAAS_pw" >> "$logFile"

read -p "Enter your root MySQL password (default is $MySQLrootPW_default): " -e t1
if [ -n "$t1" ]
then 
	MySQLrootPW="$t1"
else	
	MySQLrootPW=$MySQLrootPW_default
fi
echo "root MySQL Password: $MySQLrootPW" >> "$logFile"

read -p "Enter the private key for your captcha (Press enter for default): " -e t1
if [ -n "$t1" ]
then
	captcha="$t1"
else
	captcha="$captcha_default"
fi
echo "Captcha: $captcha" >> "$logFile"

read -p "Enter the daemon status account name (default is $daemon_default): " -e t1
if [ -n "$t1" ]
then
	daemon="$t1"
else
	daemon="$daemon_default"
fi
echo "Daemon: $daemon" >> "$logFile"

read -p "Enter the daemon status account password (default is $daemonPW_default): " -e t1
if [ -n "$t1" ]
then
	daemonPW="$t1"
else
	daemonPW="$daemonPW_default"
fi
echo "Daemon Password: $daemonPW" >> "$logFile"

read -p "Enter the name of your SAAS support person (default is $supportName_default): " -e t1
if [ -n "$t1" ]
then
	supportName="$t1"
else
	supportName="$supportName_default"
fi
echo "SAAS Support Name: $supportName" >> "$logFile"

read -p "Enter the email address for your SAAS support person (default is $supportEmail_default): " -e t1
if [ -n "$t1" ]
then
	supportEmail="$t1"
else
	supportEmail=$supportEmail_default
fi
echo "Email address: $supportEmail" >> "$logFile"

read -p "Enter your timezone (default is $timeZone_default): " -e t1
if [ -n "$t1" ]
then
	timeZone="$t1"
else
	timeZone=$timeZone_default
fi
echo "Timezone: $timeZone" >> "$logFile"

read -p "Enter a comma separated list of report recipients (default is $reportRecipList_default): " -e t1
if [ -n "$t1" ]
then
	reportRecipList="$t1"
else
	reportRecipList=$reportRecipList_default
fi
echo "Report recipient list: $reportRecipList" >> "$logFile"

while :
        do
                read -p "Enter the IP address for the server running your SAFE Archive Audit System: " -e IP
						echo "IP Address: $IP" >> "$logFile"	
                        if valid_ip $IP
                        then
                                cecho "That is not a valid IP address." $red
                                echo ""
                        else
                                break
                        fi
done

cecho "SAFE Archive needs a UNIX user called gfish to run." $cyan
# Create the gfish user
echo "Creating gfish user:" >> "$logFile"
adduser gfish >> "$logFile" 2>&1
cecho "Created the gfish user." $green
echo ""
echo ""
read -n 1 -p "Press any key to continue..."
echo ""



######################### End get user input ##############################################
#-----------------------------------------------------------------------------------------#

clear
print_banner "" "" "                   Confirm Install Choices:"
echo ""

#-----------------------------------------------------------------------------------------# 
######################## Begin Display install choices ####################################

cecho "BELOW ARE THE VALUES ENTERED: " $red
cecho "-----------------------------" $yellow
echo ""
cecho "LOCKSS Configuration:" $cyan
cecho "--------------------" $green
echo ""
cecho "LOCKSS URL:  "  $yellow
echo -ne $lockssXMLURL
echo ""  
cecho "SMTP Configuration:" $cyan
cecho "-------------------" $green
echo ""
cecho "SMTP Username: " $yellow
echo -ne "$smtpUser" 
cecho "SMTP Email: " $yellow
echo -ne "$smtpEmail" 
cecho "SMTP Password: " $yellow
echo -ne "$smtpPassword"  
cecho "SMTP Server: " $yellow
echo -ne "$smtpServer"
cecho "SMTP Port: " $yellow
echo -ne "$smtpPort"
echo ""
cecho "MySQL Configuration:" $cyan
cecho "-------------------" $green
echo ""
cecho "Database Server IP/Hostname: " $yellow
echo -ne "$IP" 
cecho "SAFE Archive DB User: " $yellow 
echo -ne "$SAAS_user"
cecho "SAFE Archive DB Password: " $yellow
echo -ne "$SAAS_pw" 
cecho "MySQL root Password: " $yellow
echo -ne "$MySQLrootPW"
echo ""
cecho "Local Configuration:" $cyan
cecho "----------------------------" $green
echo ""
cecho "Timezone: " $yellow
echo -ne "$timeZone"
cecho "Captcha Private Key: " $yellow
echo -ne "$captcha"
cecho "Daemon Account: " $yellow
echo -ne "$daemon"
cecho "Daemon Account Password: " $yellow
echo -ne "$daemonPW"
cecho "SAAS Support Name: " $yellow
echo -ne "$supportName"
cecho "SAAS Support Email: " $yellow
echo -ne "$supportEmail"
cecho "SAAS Recipient List: " $yellow
echo -ne "$reportRecipList"
echo ""
echo ""
######################## End Display install choices ######################################
#-----------------------------------------------------------------------------------------#  

#-----------------------------------------------------------------------------------------#  
######################## Begin Confirmation of install choices ############################
while :
do
	read -p "Are you sure these are the settings you'd like to use? (y/n) " -e t1

	case $t1 in
		y|Y)
			cecho "Starting install in 10 seconds... " $green
			cecho "Press <ctrl + c> to abort... "
			sleep 10 &
			spinner $!
			break
		;;
   
		n|N)
			cecho "Please re-run the installer. ($0)" $yellow
			cecho ""
			exit 0
		;;
   
		*)
		
		cecho "The only valid choices are Yes (y) and No (n). " $red
		echo ""
		;;
   
	esac
done

######################## End Confirmation of install choices ##############################
#-----------------------------------------------------------------------------------------#  

clear
print_banner "" "" "                   Firewall Configuration:"
echo ""

#-----------------------------------------------------------------------------------------# 
######################## Begin Firewall Config ############################################

cecho "Setting firewall rules... " $yellow
echo "Setting firewall rules in: /etc/sysconfig/iptables " >> "$logFile"
mv /etc/sysconfig/iptables /etc/sysconfig/iptables.bak
echo "# This script was modified by SafeArchive Installer" > $fireWall
echo "# Last Modified on $DATE" >> $fireWall
echo "*filter" >> $fireWall
echo ":INPUT ACCEPT [0:0]" >> $fireWall
echo ":FORWARD ACCEPT [0:0]" >> $fireWall
echo ":OUTPUT ACCEPT [0:0]" >> $fireWall
echo "-A INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT" >> $fireWall
echo "-A INPUT -p icmp -j ACCEPT" >> $fireWall
echo "-A INPUT -i lo -j ACCEPT" >> $fireWall
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 22 -j ACCEPT" >> $fireWall
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 3306 -j ACCEPT" >> $fireWall
cecho "Opened MySQL TCP port 3306... " $yellow
echo "Opened MySQL TCP port 3306... " >> "$logFile"
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 3700 -j ACCEPT" >> $fireWall
cecho "Opened Internet Inter-ORB Protocol TCP port 3700... " $yellow
echo "Opened Internet Inter-ORB Protocol TCP port 3700... " >> "$logFile"
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 3820 -j ACCEPT" >> $fireWall
cecho "Opened IIOP/SSL TCP port 3820... " $yellow
echo "Opened IIOP/SSL TCP port 3820... " >> "$logFile"
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 3920 -j ACCEPT" >> $fireWall
cecho "Opened IIOP/SSL with manual authentication TCP port 3920... " $yellow
echo "Opened IIOP/SSL with manual authentication TCP port 3920... " >> "$logFile"
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 4848 -j ACCEPT" >> $fireWall
cecho "Opened GlassFish Administration Console TCP port 4848... " $yellow
echo "Opened GlassFish Administration Console TCP port 4848... " >> "$logFile"
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 8080 -j ACCEPT" >> $fireWall
cecho "Opened GlassFish HTTP TCP port 8080... " $yellow
echo "Opened GlassFish HTTP TCP port 8080... " >> "$logFile"
echo "-A INPUT -m state --state NEW -m tcp -p tcp --dport 8686 -j ACCEPT" >> $fireWall
cecho "Opened GlassFish JMX connector TCP port 8686... " $yellow
echo "Opened GlassFish JMX connector TCP port 8686... " >> "$logFile"
echo "-A INPUT -j REJECT --reject-with icmp-host-prohibited" >> $fireWall
echo "-A FORWARD -j REJECT --reject-with icmp-host-prohibited" >> $fireWall
echo "COMMIT" >> $fireWall

cecho "Restarting the firewall... " $yellow
echo "Restarting the firewall... " >> "$logFile"
echo ""
service iptables restart >> "$logFile" 2>&1
sleep 2


echo ""

######################## End Firewall Config ##############################################
#-----------------------------------------------------------------------------------------#

clear
print_banner "" "" "               MySQL Database Configuration:"
echo ""

#-----------------------------------------------------------------------------------------#
######################## Begin MySQL Config ###############################################

# Setup MySQL configuration files
cp -p /etc/my.cnf /etc/my.cnf.orig >> "$logFile" 2>&1
rm -f /etc/my.cnf >> "$logFile" 2>&1
cp -fp /usr/share/mysql/my-medium.cnf /etc/my.cnf >> "$logFile" 2>&1

# Setup the MySQL users
cecho "Checking if mysqld is running... " $green
echo ""

# Check if mysqld is running
service mysqld status > /dev/null 2>&1
if [ $? -ne 0 ]
then
	cecho "mysqld is stopped... " $green
	echo "mysqld is stopped... " >> "$logFile"
	cecho "Starting mysqld... " $green
	echo "Starting mysqld... " >> "$logFile"
	echo ""
	service mysqld start >> "$logFile" 2>&1
	cecho "Adding mysqld to runlevels 3 & 5... " $green
	echo "Adding mysqld to runlevels 3 & 5... " >> "$logFile"
	chkconfig --level 35 mysqld on >> "$logFile" 2>&1
	
else
	cecho "mysqld is running... " $green
	echo "mysqld is running... " >> "$logFile"
fi

cecho "Running MySQL setup scripts... " $green
echo "Running MySQL setup scripts... " >> "$logFile"

# Set MySQL Queries
Q0="UPDATE mysql.user SET Password=PASSWORD('$MySQLrootPW') WHERE User='root';"
cecho "Setting MySQL root user password... " $green
echo "Setting MySQL root user password... " >> "$logFile"
Q1="GRANT all ON *.* to 'root'@'$IP' IDENTIFIED BY '$MySQLrootPW';"
cecho "Setting MySQL root user privilges... " $green
echo "Setting MySQL root user privilges... " >> "$logFile"
Q2="GRANT all ON *.* to '$SAAS_user'@'%' IDENTIFIED by '$SAAS_pw';"
Q3="GRANT all ON *.* to '$SAAS_user'@'127.0.0.1' IDENTIFIED by '$SAAS_pw';"
Q4="GRANT all ON *.* to '$SAAS_user'@'$IP' IDENTIFIED by '$SAAS_pw';"
Q5="GRANT all ON *.* to '$SAAS_user'@'localhost' IDENTIFIED by '$SAAS_pw';"
cecho "Setting MySQL SAAS database user privileges... " $green
echo "Setting MySQL SAAS database user privileges... " >> "$logFile"
Q6="DELETE from mysql.user WHERE user='';"
Q7="FLUSH PRIVILEGES;"
Q8="CREATE DATABASE safe_archive_system_db;"
SQL="${Q0}${Q1}${Q2}${Q3}${Q4}${Q5}${Q6}${Q7}${Q8}"

# Run the MySQL Queries
$MySQLbin -u root -e "$SQL" >> "$logFile" 2>&1 

cecho "Restarting the MySQL server... " $green
echo "Restarting the MySQL server... " >> "$logFile"
echo ""
service mysqld restart >> "$logFile" 2>&1

cecho "MySQL user setup is complete... " $green
echo ""


echo ""

######################## End MySQL Config #################################################  
#-----------------------------------------------------------------------------------------#

clear
print_banner "" "" "              Java Install/Configuration:"
echo ""

#-----------------------------------------------------------------------------------------#
######################## Begin Java Install ###############################################

cd $MyPWD
cp software/jdk-7u17-linux-i586.tar.gz /opt
cd /opt

cecho "Unpacking Java, please wait... " $magenta
tar --no-same-owner -xvf jdk-7u17-linux-i586.tar.gz >> "$logFile" &
spinner $!
echo ""

#Create the Java SymLinks
if [ -a "/usr/bin/java" ]
then
        cecho "Deleting symlink to java... " $magenta
        mv /usr/bin/java /usr/bin/java.bak
fi

if [ -a "/usr/bin/javac" ]
then
        cecho "Deleting symlink to javac... " $magenta
        mv /usr/bin/javac /usr/bin/javac.bak
fi

echo ""

cecho "Creating java symlink... " $magenta
ln -s /opt/jdk1.7.0_17/bin/java /usr/bin/java

cecho "Creating javac symlink... " $magenta
ln -s /opt/jdk1.7.0_17/bin/javac /usr/bin/javac

echo ""

# Create the .bash_profile additions
echo "# Added by SAAS installer script" >> /root/.bash_profile
echo "PATH=\$PATH:\$JAVA_HOME:\$JAVA_HOME/bin" >> /root/.bash_profile
echo "JAVA_HOME=/opt/jdk1.7.0_17" >> /root/.bash_profile
echo "export JAVA_HOME" >> /root/.bash_profile
echo "export PATH" >> /root/.bash_profile
cecho "Set root's JAVA_HOME... " $magenta

echo "# Added by SAAS installer script" >> /home/gfish/.bash_profile
echo "PATH=\$PATH:\$JAVA_HOME:\$JAVA_HOME/bin" >> /home/gfish/.bash_profile
echo "JAVA_HOME=/opt/jdk1.7.0_17" >> /home/gfish/.bash_profile
echo "export JAVA_HOME" >> /home/gfish/.bash_profile
echo "export PATH" >> /home/gfish/.bash_profile
cecho "Set gfish's JAVA_HOME... " $magenta
echo ""

source /root/.bash_profile
su gfish -c "source /home/gfish/.bash_profile"


echo ""

######################## End Java Install #################################################
#-----------------------------------------------------------------------------------------#

clear
print_banner "" "" "              GlassFish Install/Configuration:"

#-----------------------------------------------------------------------------------------#
######################## Begin GlassFish Install ##########################################

# Unpack the GlassFish server
cecho "Installing GlassFish Application Server... " $cyan
cd $MyPWD
cp software/glassfish-3.1.2.2-ml.zip /usr/local
cd /usr/local
cecho "Unpacking GlassFish, please wait... " $cyan
unzip glassfish-3.1.2.2-ml.zip >> "$logFile" &
spinner $!
echo ""
cd $MyPWD


######################## End GlassFish Install ############################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin Configure SAAS XML Config Files ############################
cecho "Configuring SAAS XML files... " $cyan
gFishConf="/usr/local/glassfish3/glassfish/domains/domain1/config"

# saas-local-config.xml
touch $gFishConf/saas-local-config.xml
echo "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>" > $gFishConf/saas-local-config.xml 
echo "<!DOCTYPE properties SYSTEM \"http://java.sun.com/dtd/properties.dtd\">" >> $gFishConf/saas-local-config.xml
echo "<properties>" >> $gFishConf/saas-local-config.xml
echo "<comment></comment>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.audit.report.cronjob.id\">auditreportCJ</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.build.release.version\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.support.contactus.emailaddress\">$supportEmail</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.pacesettercronjob.id\">pacesetterCJ</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.svnrepository.loginname\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.audit.report.interval.origin\">LAST</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.build.sourcefile.version\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.lockss.xml.url\">$lockssXMLURL</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.svnrepository.location\">/usr/safe/svn</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.svnrepository.loginpassword\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.daemonstatus.port\">8081</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.etlcronjob.hour\">0</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.etlcronjob.id\">ETLCJ</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.daemonstatus.groupname\">NA</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.captcha.publickey\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.build.date\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.member.ip.tag\">id.initialV3PeerList</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.configproperties.lastsaved\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.daemonstatus.account\">$daemon</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.audit.report.cronjob.hour\">1</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.ip.fromlockssxml\"></entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.svnrepository.url\">file:///usr/safe/svn/</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.support.contactus.emailrecipientname\">$supportName</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.captcha.privatekey\">$captcha</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.pacesettercronjob.hour\">23</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.daemonstatus.password\">$daemonPW</entry>" >> $gFishConf/saas-local-config.xml
echo "<entry key=\"saas.daemonstatusdata.lastupdated\"></entry>" >> $gFishConf/saas-local-config.xml
echo "</properties>" >> $gFishConf/saas-local-config.xml
echo "Created saas-local-config.xml" >> "$logFile"

# saas-audit-config.xml
touch $gFishConf/saas-audit-config.xml
echo "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>" > $gFishConf/saas-audit-config.xml 
echo "<!DOCTYPE properties SYSTEM \"http://java.sun.com/dtd/properties.dtd\">" >> $gFishConf/saas-audit-config.xml
echo "<properties>" >> $gFishConf/saas-audit-config.xml
echo "<comment></comment>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schemafilename\">lockss_audit_schema_instance.xml</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.plnxpathfilename\">lockss_audit_diff_xpaths.xml</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.configfile.dir\">/usr/safe/data/audit_input_files</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.auditconfigproperties.lastsaved\"></entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.xsdfilename\">SSPSchema_v1_05.xsd</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.subject.optionset.filename\">saas-audit-subject-set.txt</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.ownerinst.optionset.filename\">saas-audit-owner-inst-set.txt</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.au.updatefrequency\">7</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.reportfile.dir\">/usr/safe/data/audit_output_files</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.au.verificationfrequency\">21</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.au.numberreplicates\">3</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.config.savedTargetIps\"/>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.birtviewer.access.account\">birtviewer</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.xsdfilename\">lockss_audit_report.xsd</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.config.timestamp.pattern\">yyyy-MM-dd'T'HH:mm:ss zz</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.reportpdffilename\">lockss_audit_report.pdf</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schemafile.dir\">/usr/safe/data/audit_input_files</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.birtviewer.access.password\">birtviewer</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.au.size.max\">1024</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.geounitcodetoregioncode.filename\">us-state-code-to-region-code.properties</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.emailnotice.recipients\">$reportRecipList</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schemafile.svnpath\">/trunk/audit_input_files</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.au.grouppolicy.enabled\">false</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.birtviewer.servername\">$IP</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.interval\">7</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.reportfilename\">lockss_audit_report.xml</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.report.birtviewer.portnumber\">8080</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schemafilename.base\">lockss_audit_schema_instance_</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.geounitcodetolabel.filename\">us-state-code-to-label.properties</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.reportfilename.base\">lockss_audit_report_</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.targetIp\"></entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.reportfile.svnpath\">/trunk/audit_output_files</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.au.replicationduration\">21</entry>" >> $gFishConf/saas-audit-config.xml
echo "<entry key=\"saas.audit.schema.regioncodetolabel.filename\">us-census-region-modified-code-to-label.properties</entry>" >> $gFishConf/saas-audit-config.xml
echo "</properties>" >> $gFishConf/saas-audit-config.xml
echo "Created saas-audit-config.xml" >> "$logFile"

######################## End Configure SAAS XML Config Files ##############################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin GlassFish Configuration ####################################

cecho "Copying jar files to domain library... " $cyan
cp software/*.jar /usr/local/glassfish3/glassfish/domains/domain1/lib
chown -R gfish /usr/local/glassfish3
chgrp -R gfish /usr/local/glassfish3

cecho "Cleaning up... " $cyan
echo ""
rm -f /usr/local/glassfish-*-ml.zip

# Start the GlassFish Domain
su gfish -c "$pathToBin/asadmin start-domain" >> "$logFile" 2>&1
if [ $? -ne 0 ]
then
	cecho "GlassFish is not starting... " $cyan
	cecho "Fixing the problem... " $cyan
	echo ""
	my_host="`echo $HOSTNAME | awk -F'.' '{print $1}'`"
	cp /etc/hosts /etc/hosts.bak
	echo "# Edited by SAAS Installer" >> /etc/hosts
	echo "# Last Modified: $DATE" >> /etc/hosts
	echo "127.0.0.1    $HOSTNAME     $my_host" >> /etc/hosts
	echo "$IP     $HOSTNAME     $my_host" >> /etc/hosts
	
	su gfish -c "$pathToBin/asadmin start-domain" >> "$logFile" 2>&1
else
	cecho "Started GlassFish domain... " $cyan
fi

# Create a Temporary Password File
touch /tmp/password.txt
chmod 644 /tmp/password.txt 
echo "AS_ADMIN_PASSWORD=" > /tmp/password.txt
echo "AS_ADMIN_NEWPASSWORD=adminadmin" >> /tmp/password.txt

# Set Admin's Password
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt change-admin-password" >> "$logFile" 2>&1

# Update the password file
echo "AS_ADMIN_PASSWORD=adminadmin" > /tmp/password.txt

# Enable Secure Admin
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt enable-secure-admin" >> "$logFile" 2>&1
su gfish -c "$pathToBin/asadmin restart-domain" >> "$logFile" 2>&1
cecho "Restarting GlassFish... " $cyan
spinner $!

# Create JVM Options
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options -Dsaas.locks.xml.url=$lockssXMLURL" >> "$logFile" 2>&1 
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options -Dsaas.jdbc.jndi.name=jdbc/saasDS" >> "$logFile" 2>&1 
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options -Dsaas.localconfig.file=\$\{com.sun.aas.instanceRoot\}/config/saas-local-config.xml" >> "$logFile"  2>&1 
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options -Dsaas.audit.config.file=\$\{com.sun.aas.instanceRoot\}/config/saas-audit-config.xml" >> "$logFile"  2>&1 
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options \'-Dsaas.ejb.jndi.modulename=java\:global/safearchiveauditsystem-ear/safearchiveauditsystem-ejb-1.1/\'" >> "$logFile"  2>&1 
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options -Dsaas.captcha.privatekey=$captcha" >> "$logFile"  2>&1 
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-jvm-options -Dsaas.timezone=$timeZone" >> "$logFile"  2>&1
cecho "Created JVM Options... " $cyan

# Create the JDBC Connection Pool
su gfish -c "$pathToBin/asadmin create-jdbc-connection-pool --datasourceclassname com.mysql.jdbc.jdbc2.optional.MysqlDataSource --restype=javax.sql.DataSource --property=\"user=$SAAS_user:password=$SAAS_pw:databaseName=safe_archive_system_db:serverName=$IP:URL=jdbc\\:mysql\\://$IP\\:3306/safe_archive_system_db:Url=jdbc\\:mysql\\://$IP\\:3306/safe_archive_system_db:AllowLoadLocalInfile=true:AllowMultiQueries=false:AllowNanAndInf=false:AllowUrlInLocalInfile=false:AlwaysSendSetIsolation=true:AutoClosePStmtStreams=false:AutoDeserialize=false:AutoGenerateTestcaseScript=false:AutoReconnectForPools=false:AutoSlowLog=true:BlobsAreStrings=false:BlobSendChunkSize=1048576:CacheCallableStatements=false:CacheCallableStmts=false:CachePreparedStatements=false:CachePrepStmts=false:CacheResultSetMetadata=false:CacheServerConfiguration=false:CallableStatementCacheSize=100:CallableStmtCacheSize=100:CapitalizeTypeNames=true:ClientCertificateKeyStoreType=JKS:ClientInfoProvider=com.mysql.jdbc.JDBC4CommentClientInfoProvider:ClobberStreamingResults=false:CompensateOnDuplicateKeyUpdateCounts=false:ConnectTimeout=0:ContinueBatchOnError=true:CreateDatabaseIfNotExist=false:DefaultFetchSize=0:DontTrackOpenResources=false:DumpMetadataOnColumnNotFound=false:DumpQueriesOnException=false:DynamicCalendars=false:ElideSetAutoCommits=false:EmptyStringsConvertToZero=true:EmulateLocators=false:EmulateUnsupportedPstmts=true:EnablePacketDebug=false:EnableQueryTimeouts=true:ExplainSlowQueries=false:FailOverReadOnly=true:FunctionsNeverReturnBlobs=false:GatherPerfMetrics=false:GatherPerformanceMetrics=false:GenerateSimpleParameterMetadata=false:HoldResultsOpenOverStatementClose=false:IgnoreNonTxTables=false:IncludeInnodbStatusInDeadlockExceptions=false:IncludeThreadDumpInDeadlockExceptions=false:IncludeThreadNamesAsStatementComment=false:InitialTimeout=2:InteractiveClient=false:IsInteractiveClient=false:JdbcCompliantTruncationForReads=true:JdbcCompliantTruncation=true:LoadBalanceAutoCommitStatementThreshold=0:LoadBalanceBlacklistTimeout=0:LoadBalanceEnableJMX=false:LoadBalanceExceptionChecker=com.mysql.jdbc.StandardLoadBalanceExceptionChecker:LoadBalancePingTimeout=0:LoadBalanceStrategy=random:LoadBalanceValidateConnectionOnSwapServer=false:LocatorFetchBufferSize=1048576:LoggerClassName=com.mysql.jdbc.log.StandardLogger:Logger=com.mysql.jdbc.log.StandardLogger:LoginTimeout=0:LogSlowQueries=false:LogXaCommands=false:MaintainTimeStats=true:MaxAllowedPacket=-1:MaxQuerySizeToLog=2048:MaxReconnects=3:MaxRows=-1:MetadataCacheSize=50:NetTimeoutForStreamingResults=600:NoAccessToProcedureBodies=false:NoDatetimeStringSync=false:NoTimezoneConversionForTimeType=false:NullCatalogMeansCurrent=true:NullNamePatternMatchesAll=true:OverrideSupportsIntegrityEnhancementFacility=false:PacketDebugBufferSize=20:PadCharsWithSpace=false:Paranoid=false:Pedantic=false:PinGlobalTxToPhysicalConnection=false:PopulateInsertRowWithDefaultValues=false:Port=3306:PortNumber=3306:PreparedStatementCacheSize=25:PreparedStatementCacheSqlLimit=256:PrepStmtCacheSize=25:PrepStmtCacheSqlLimit=256:ProcessEscapeCodesForPrepStmts=true:ProfilerEventHandler=com.mysql.jdbc.profiler.LoggingProfilerEventHandler:ProfileSql=false:ProfileSQL=false:QueriesBeforeRetryMaster=50:QueryTimeoutKillsConnection=false:ReconnectAtTxEnd=false:RelaxAutoCommit=false:ReportMetricsIntervalMillis=30000:RequireSSL=false:ResultSetSizeThreshold=100:RetainStatementAfterResultSetClose=false:RetriesAllDown=120:RewriteBatchedStatements=false:RollbackOnPooledClose=true:RoundRobinLoadBalance=false:RunningCTS13=false:SecondsBeforeRetryMaster=30:SelfDestructOnPingMaxOperations=0:SelfDestructOnPingSecondsLifetime=0:SlowQueryThresholdMillis=2000:SlowQueryThresholdNanos=0:SocketFactoryClassName=com.mysql.jdbc.StandardSocketFactory:SocketFactory=com.mysql.jdbc.StandardSocketFactory:SocketTimeout=0:StrictFloatingPoint=false:StrictUpdates=true:TcpKeepAlive=true:TcpNoDelay=true:TcpRcvBuf=0:TcpSndBuf=0:TcpTrafficClass=0:TinyInt1isBit=true:TraceProtocol=false:TransformedBitIsBoolean=false:TreatUtilDateAsTimestamp=true:TrustCertificateKeyStoreType=JKS:UltraDevHack=false:UseAffectedRows=false:UseBlobToStoreUTF8OutsideBMP=false:UseColumnNamesInFindColumn=false:UseCompression=false:UseCursorFetch=false:UseDirectRowUnpack=true:UseDynamicCharsetInfo=true:UseFastDateParsing=true:UseFastIntParsing=true:UseGmtMillisForDatetimes=false:UseHostsInPrivileges=true:UseInformationSchema=false:UseJDBCCompliantTimezoneShift=false:UseJvmCharsetConverters=false:UseLegacyDatetimeCode=true:UseLocalSessionState=false:UseLocalTransactionState=false:UseNanosForElapsedTime=false:UseOldAliasMetadataBehavior=false:UseOldUTF8Behavior=false:UseOnlyServerErrorMessages=true:UseReadAheadInput=true:UseServerPreparedStmts=false:UseServerPrepStmts=false:UseSqlStateCodes=true:UseSSL=false:UseSSPSCompatibleTimezoneShift=false:UseStreamLengthsInPrepStmts=true:UseTimezone=false:UseUltraDevWorkAround=false:UseUnbufferedInput=true:UseUnicode=true:UseUsageAdvisor=false:VerifyServerCertificate=true:YearIsDateType=true:ZeroDateTimeBehavior=exception\" saasDbPool --user admin --passwordfile /tmp/password.txt" >> "$logFile" 2>&1
cecho "Created JDBC Connection Pool... " $cyan

# Create the JDBC Resource
su gfish -c "$pathToBin/asadmin create-jdbc-resource --connectionpoolid saasDbPool jdbc/saasDS --user admin --passwordfile /tmp/password.txt" >> "$logFile" 2>&1
cecho "Created JDBC Resource... " $cyan

# Create Java Mail Session
su gfish -c "$pathToBin/asadmin --user admin --passwordfile /tmp/password.txt create-javamail-resource --mailhost $smtpServer --mailuser $smtpUser --fromaddress $smtpEmail --property mail.smtp.socketFactory.class=javax.net.ssl.SSLSocketFactory:mail.smtp.password=$smtpPassword:mail.smtp.auth=true:mail.smtp.socketFactory.fallback=false:mail.smtp.port=$smtpPort:mail.smtp.socketFactory.port=$smtpPort mail/saasMailSession" >> "$logFile" 2>&1
cecho "Created Java Mail Session... " $cyan

# Create JMS Resources
su gfish -c "$pathToBin/asadmin create-jms-resource --restype javax.jms.QueueConnectionFactory --property ClientId=MyID jms/SAASPostAuditReportActionQueueConnectionFactory --user admin --passwordfile /tmp/password.txt" >> "$logFile" 2>&1
su gfish -c "$pathToBin/asadmin create-jms-resource --restype javax.jms.QueueConnectionFactory --property ClientId=MyID jms/SAASPostETLActionQueueConnectionFactory --user admin --passwordfile /tmp/password.txt" >> "$logFile" 2>&1
su gfish -c "$pathToBin/asadmin create-jms-resource --restype javax.jms.Queue --property Name=SAASPostAuditReportAction jms/SAASPostAuditReportAction --user admin --passwordfile /tmp/password.txt" >> "$logFile" 2>&1
su gfish -c "$pathToBin/asadmin create-jms-resource --restype javax.jms.Queue --property Name=SAASPostETLAction jms/SAASPostETLAction --user admin --passwordfile /tmp/password.txt" >> "$logFile" 2>&1
cecho "Created JMS Resources... " $cyan


echo ""

# Create curator user
echo "AS_ADMIN_USERPASSWORD=curator" >> /tmp/password.txt
su gfish -c "$pathToBin/asadmin create-file-user --user admin --passwordfile /tmp/password.txt --groups saasCuratorGroup curator" >> "$logFile" 2>&1 
cecho "Created SAAS curator user... " $cyan

# Create birtviwer user
echo "AS_ADMIN_PASSWORD=adminadmin" > /tmp/password.txt
echo "AS_ADMIN_USERPASSWORD=birtviewer" >> /tmp/password.txt
su gfish -c "$pathToBin/asadmin create-file-user --user admin --passwordfile /tmp/password.txt --groups saasCuratorGroup birtviewer" >> "$logFile" 2>&1
cecho "Created SAAS birtviewer user... " $cyan

# Create administrator user
echo "AS_ADMIN_PASSWORD=adminadmin" > /tmp/password.txt
echo "AS_ADMIN_USERPASSWORD=administrator" >> /tmp/password.txt
su gfish -c "$pathToBin/asadmin create-file-user --user admin --passwordfile /tmp/password.txt --groups saasAdminGroup administrator" >> "$logFile" 2>&1
cecho "Created SAAS administrator user... " $cyan
echo ""

# Restart the GlassFish Domain so changes will take effect
su gfish -c "$pathToBin/asadmin restart-domain" >> "$logFile" 2>&1 
cecho "Restarting GlassFish... " $cyan
sleep 7 &
spinner $!

# Add GlassFish to startup
cp $MyPWD/etc/glassfish /etc/init.d
chkconfig --add glassfish
chkconfig --level 345 glassfish on
cecho "GlassFish added to startup..." $cyan

######################## End GlassFish Configuration ######################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin birt.war deployment ########################################

# Put .ear and .war files in a place that gfish has permission to use
cd $MyPWD
cp deploy/*.war /tmp
cp deploy/*.ear /tmp

# Deploy birt.war 
echo "AS_ADMIN_PASSWORD=adminadmin" > /tmp/password.txt
cecho "Deploying birt.war... " $cyan
su gfish -c "$pathToBin/asadmin deploy --user=admin --passwordfile /tmp/password.txt /tmp/birt.war" >> "$logFile" 2>&1 &
spinner $!

######################## End birt.war deployment ##########################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin svn configuration ##########################################

cecho "Creating SAFE Archive directory structure... " $cyan
echo ""
mkdir /usr/safe >> "$logFile" 2>&1
mkdir /usr/safe/data >> "$logFile" 2>&1
mkdir /usr/safe/data/audit_input_files >> "$logFile" 2>&1
mkdir /usr/safe/data/audit_output_files >> "$logFile" 2>&1

cecho "Copying Audit report related configuration files... " $cyan
echo ""
cd $MyPWD

cp install_files/*.xsd $input_files >> "$logFile" 2>&1
cp install_files/*.xml $input_files >> "$logFile" 2>&1
cp install_files/*.properties $input_files >> "$logFile" 2>&1
cp install_files/saas*.txt $input_files >> "$logFile" 2>&1

chown -R gfish /usr/safe >> "$logFile" 2>&1
chgrp -R gfish /usr/safe >> "$logFile" 2>&1

cecho "Creating Subversion repository... " $cyan
echo ""
svnadmin create /usr/safe/svn  >> "$logFile" 2>&1
svn import /usr/safe/data file:///usr/safe/svn/trunk -m "initial import"  >> "$logFile" 2>&1

######################## End svn configuration ############################################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin SAFE Archive Audit System Deployment #######################

cecho "Deploying SAAS .ear file... " $cyan
su gfish -c "$pathToBin/asadmin deploy --user=admin --passwordfile /tmp/password.txt /tmp/safearchiveauditsystem-ear.ear" >> "$logFile" 2>&1 &
spinner $!

# Remove Tempoary Password, .war, & .ear files
rm /tmp/password.txt
rm /tmp/*.war
rm /tmp/*.ear

######################## End SAFE Archive Audit System Deployment #########################
#-----------------------------------------------------------------------------------------#

#-----------------------------------------------------------------------------------------#
######################## Begin Post SAAS Setup MySQL script ###############################

# MySQL to be run directly after GlassFish deployment
cd $MyPWD/install_files
cecho "Filling the SAFE Archive constants table... " $cyan
echo ""
echo ""
Q9="USE safe_archive_system_db;"
Q10="LOAD DATA LOCAL INFILE 'trac_qq.txt' INTO TABLE trac_audit_checklist_criteria_data (aspect_id, criterion);"
SQL="${Q9}${Q10}"
$MySQLbin -u root -p$MySQLrootPW -e "$SQL"  
cd $MyPWD

echo ""

######################## End Post SAAS Setup MySQL script ###############################
#-----------------------------------------------------------------------------------------#

clear
print_banner

#-----------------------------------------------------------------------------------------#
######################## Begin Setup Complete Message #####################################

cecho "Setup is complete: " $green
echo ""
cecho "-------------------" $white
cecho "To begin using your SAFE Archive Audit System go to " $yellow
cecho "http://$IP:8080/safearchiveauditsystem-web/faces/" $yellow
echo -e "\E[31;40mindex.xhtml" 
echo ""
tput sgr0

######################## End Setup Complete Message #######################################
#-----------------------------------------------------------------------------------------#
